// Import necessary functions and components from the D3.js and TopoJSON libraries
import {
  select, // To select DOM elements
  json, // To load JSON data
  geoPath, // To generate SVG path data based on GeoJSON/TopoJSON
  geoMercator, // To use the Mercator projection for the map
  scaleOrdinal, // To create an ordinal scale for coloring
  schemeCategory10, // To access a set of 10 categorical colors
} from 'd3';
import { feature, mesh } from 'topojson'; // To convert TopoJSON back to GeoJSON

// Select the SVG element in the DOM to be used for rendering the map
const svg = select('svg');

// Set up the map projection; geoMercator is commonly used for world maps
const projection = geoMercator()
  .translate([-600, 590]) // Sets the translation to position the map within the SVG
  .scale([790]); // Sets the zoom level of the map

// Create a path generator using the defined projection
const pathGenerator = geoPath().projection(projection);

// Create a color scale using one of D3's categorical color schemes
const colorScale = scaleOrdinal(schemeCategory10);
/////////////////////////////////////////

const womenDataUrl = d3.csv(
  'https://gist.githubusercontent.com/nitanagdeote/92ab25e2efe3bbde24fd87f87014bdec/raw/2b03fc80a502b8a57fe40a47a0288a4ce0cc98fa/women-missing-per-total-women-population.csv',
);
womenDataUrl.then((data) => console.log(data));

//////////////////////////////////////
// Load the geographical data in TopoJSON format from a remote source
json(
  'https://gist.githubusercontent.com/GaddamThanmayeeReddy/e7fdef9f0fee7ff9fa43c47b0f9ce340/raw/41a63c95dd0029d1dfdcc3d948ca079016577d02/countrymap.json',
).then((data) => {
  // Convert the TopoJSON to GeoJSON for the specific object layer, here 'IND_adm1'
  const countryShapes = feature(
    data,
    data.objects.IND_adm1,
  );
  console.log(countryShapes);
  // Remove the first feature from the array, if needed, using shift()
  countryShapes.features.shift();

  // Bind the GeoJSON features to path elements and append them to the SVG
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states') // Assign a class for potential styling
    .attr('fill', (d) => colorScale(d.properties.NAME_1)) // Color the paths based on a property, using the ordinal color scale
    .attr('d', (d) => pathGenerator(d)) // Generate the SVG path data
    .append('title') // Add a title element for a simple tooltip
    .text((d) => d.properties.NAME_1); // Set the tooltip text

  // Optionally, add labels to each feature
  svg
    .selectAll('text')
    .data(countryShapes.features)
    .enter()
    .append('text')
    .text((d) => d.properties.NAME_1) // Text from a property of each feature
    .attr('x', (d) => pathGenerator.centroid(d)[0]) // Position at the centroid of each feature
    .attr('y', (d) => pathGenerator.centroid(d)[1])
    .attr('text-anchor', 'middle') // Center the text
    .attr('font-size', '9px'); // Set the font size
});
